@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: admin.py 11593 2019-05-29 06:23:49Z Lavender $
+# $Id: admin.py 11601 2019-06-01 19:27:05Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2019-05-29 15:23:49 +0900 (週三, 29 五月 2019) $
-# $Revision: 11593 $
+# $Date: 2019-06-02 03:27:05 +0800 (週日, 02 六月 2019) $
+# $Revision: 11601 $
 
 import six
 import urllib
@@ -30,7 +30,7 @@ class CommentAdmin(admin.ModelAdmin):
     
     readonly_fields = [
         'getUrl', 'user', "email", 'facebook', 
-        'facebookUser', 'message', 'createDate']
+        'facebookUser', 'facebookMsgId', 'message', 'createDate']
         
     list_display = ['id', 'getUrl', 'user', "email", 'facebookUser',
                     'getMessage', 'display']
