@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 12209 2020-05-13 07:27:11Z Lavender $
+# $Id: __init__.py 12224 2020-05-15 09:54:33Z Andy $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Lavender $
-# $Date: 2020-05-13 15:27:11 +0800 (週三, 13 五月 2020) $
-# $Revision: 12209 $
+# $Author: Andy $
+# $Date: 2020-05-15 17:54:33 +0800 (週五, 15 五月 2020) $
+# $Revision: 12224 $
 
 import json
 import requests
@@ -24,6 +24,9 @@ import six
 from django.utils.http import urlquote
 from django.conf import settings as _settings
 from django.utils.translation import ugettext_lazy as _
+from django.conf.urls import url, include
+
+from Iuppiter.DjangoUtil import DJANGO_VERSION
 
 if six.PY3:
     from urllib.parse import urlparse
@@ -113,3 +116,23 @@ def getAPIData(url, fieldName,
         return reaction + share + comment
     return data.get("engagement", {}).get(fieldName, None)
 
+def patterns(prefix, *args): 
+    if DJANGO_VERSION >= 11100: # django >= 1.11
+        return list(args)
+    else:
+        from django.conf.urls import patterns as _patterns
+        
+        return _patterns(prefix, *args)
+
+def attachURLs(settings, urlpatterns):
+    """
+    Attach patched (for example, debug and admin...etc.) urlpatterns.
+    It must be called in urls.py by passing urlpatterns.
+
+    @param settings Django project's settings module.
+    @param urlpatterns urlpatterns in urls.py.
+    """
+    urlpatterns += patterns('',
+        url(r'^', include('Zephyrus.facebook.urls')),
+    )
+
