@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: views.py 12044 2020-04-05 11:36:35Z Lavender $
+# $Id: views.py 12209 2020-05-13 07:27:11Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2020-04-05 19:36:35 +0800 (週日, 05 四月 2020) $
-# $Revision: 12044 $
+# $Date: 2020-05-13 15:27:11 +0800 (週三, 13 五月 2020) $
+# $Revision: 12209 $
 
 import json
 
@@ -29,43 +29,91 @@ from django.utils.translation import ugettext as _
 from django.urls import reverse
 
 from Iuppiter.Logging import createLogger
-from Zephyrus.facebook import MANAGE_PAGES_STATE
+from Zephyrus.facebook import MANAGE_PAGES_STATE, SCOPE
 from Zephyrus.facebook import settings as FBSettings
 from Zephyrus.facebook import getCommentURL, getAPIData
 from Zephyrus.facebook.models import APIData, FacebookSettings
 
 logger = createLogger(__name__)
 
-def createAuthorizationURL(request, scope=["manage_pages", "pages_show_list"], state=MANAGE_PAGES_STATE):
+def createAuthorizationURL(request, scope=SCOPE, state={"code": MANAGE_PAGES_STATE,}, redirectToURL=None):
     scope = ",".join(scope)
-    redirectUrl = "https://%s%s" % (request.META['HTTP_HOST'], reverse("facebookAuthorization"))
+    redirectURL = "https://%s%s" % (request.META['HTTP_HOST'], reverse("facebookAuthorization"))
     url = ("https://www.facebook.com/v6.0/dialog/oauth?client_id="
            "%s&redirect_uri=%s&scope=%s") % (
-            FBSettings.ZEPHYRUS_FACEBOOK_DEFAULT_APP_ID, redirectUrl, scope)
+            FBSettings.ZEPHYRUS_FACEBOOK_DEFAULT_APP_ID, redirectURL, scope)
+            
+    if redirectToURL:
+        state.update({
+            "redirectToURL": redirectToURL,
+        })
             
     if state:
-        url = url + "&state=%s" % state
+        url = url + "&state=%s" % json.dumps(state)
     
     return url
     
 def createAccessTokenAPIURL(request, code):
-    redirectUrl = "https://%s%s" % (request.META['HTTP_HOST'], reverse("facebookAuthorization"))
+    redirectURL = "https://%s%s" % (request.META['HTTP_HOST'], reverse("facebookAuthorization"))
     url = ("https://graph.facebook.com/v6.0/oauth/access_token"
            "?client_id=%s&redirect_uri=%s&client_secret=%s&code=%s") % (
-           FBSettings.ZEPHYRUS_FACEBOOK_DEFAULT_APP_ID, redirectUrl, 
+           FBSettings.ZEPHYRUS_FACEBOOK_DEFAULT_APP_ID, redirectURL, 
            FBSettings.ZEPHYRUS_FACEBOOK_DEFAULT_APP_SECRET, code)
     return url
+    
+class FacebookAccessTokenCreateView(View):
 
+    def get(self, request, *args, **kwargs):
+        referer = request.META.get('HTTP_REFERER')
+        # 要使用這個需要同一個站內的連結
+        if referer:
+            redirectURL = "%s://%s%s" % (
+                request.scheme, request.META['HTTP_HOST'], reverse('facebookAccessTokenReturn'))
+            
+            # 使用這個 view 需要以下兩種參數
+            data = "redirect=%s&password=%s" % (redirectURL, FBSettings.ZEPHYRUS_FACEBOOK_DEFAULT_PASSWORD)
+            
+            return redirect("%s%s?%s" % (
+                FBSettings.ZEPHYRUS_FACEBOOK_DEFAULT_GET_ACCESS_TOKEN_URL, 
+                reverse('facebookAuthorizationRedirect'), data))
+        else:
+            raise Http404()
+        
+class FacebookAccessTokenReturnView(View):
+
+    def get(self, request, *args, **kwargs):
+        accessToken = request.GET.get("token")
+        msg = request.GET.get("msg")
+        
+        if accessToken:
+            # save accessToken
+            config, created = FacebookSettings.objects.get_or_create()
+            config.accessToken = accessToken
+            config.save()
+            
+        return render(request, "facebook/Authorization.html", {"msg": msg,})
+        
 class AuthorizationRedirectView(View):
 
     def get(self, request, *args, **kwargs):
-        return redirect(createAuthorizationURL(request))
+        # 要使用這個 view 需要有 password redirectToURL
+        redirectToURL = request.GET.get("redirect")
+        password = request.GET.get("password")
+        if redirectToURL and password == FBSettings.ZEPHYRUS_FACEBOOK_DEFAULT_PASSWORD:
+            return redirect(createAuthorizationURL(request, redirectToURL=redirectToURL))
+        raise Http404()
     
 
 class FacebookAuthorizationView(View):
+    
+    SUCCESS_MESSAGE = _("Authorization successfully, this window will close automatically.")
+    ERROR_MESSAGE = _("Authorization failed, please try again. This window will close automatically.")
 
     def get(self, request, *args, **kwargs):
-        if MANAGE_PAGES_STATE == request.GET.get("state"):
+        state = json.loads(request.GET.get("state", "{}"))
+        redirectToURL = state.get("redirectToURL")
+        code = state.get("code")
+        if MANAGE_PAGES_STATE == code and redirectToURL:
             # dealwith auth as access token
             code = request.GET.get("code")
             url = createAccessTokenAPIURL(request, code)
@@ -76,19 +124,17 @@ class FacebookAuthorizationView(View):
                 accessToken = data.get("access_token")
                 
                 if accessToken:
-                    # save accessToken
-                    config, created = FacebookSettings.objects.get_or_create()
-                    config.accessToken = accessToken
-                    config.save()
                     logger.info("Success get access token from facebook API: %s" % data)
-                    msg = _("Authorization successfully, this window will close automatically.")
+                    msg = self.SUCCESS_MESSAGE
                 else:
                     logger.error("Can't get access token from facebook API: %s" % data)
-                    msg = _("Authorization failed, please try again. This window will close automatically.")
+                    msg = self.ERROR_MESSAGE
             except Exception as e:
                 logger.error("Can't get access token from facebook API: %s" % e)
-                msg = _("Authorization failed, please try again. This window will close automatically.")
-            return render(request, "facebook/Authorization.html", {"msg": msg,})
+                msg = self.ERROR_MESSAGE
+                
+            redirectToURL = "%s?token=%s&msg=%s" % (redirectToURL, accessToken, msg)
+            return redirect(redirectToURL)
         raise Http404()
    
 if "Zephyrus.comment" in settings.INSTALLED_APPS:
